/* We now turn to real terms to compute multifactor productivity measures */

/* Multifactor productivity measures describe the relationship between output in 
real terms and the inputs involved in its production.  They do not measure the
specific contributions of labor, capital, or any other factor of production.  

Rather, multifactor productivity is designed to measure the joint influences of
output, capital, and labor on economic growth of technological change, 
efficiency improvements, returns to scale, reallocation of resources due to 
shifts in factor inputs across industries, and other factors.

According to the BLS, the multifactor productivity indexes for private business and private nonfarm
business are derived by dividing an output index by an index of labor input and
capital services.  The output indexes are computed as chained superlative 
indexes (Fisher Ideal indexes) of components of real output.  For the years 
1948 to 2002, BEA supplies the output indexes.  BLS adjusts these to eliminate 
the output of government enterprises. */



/* cambiar nominal to real and viceversa */

gen kp_c=kp
gen kd_c=kd
gen kg_c=kg

replace kp = kp_r
replace kd = kd_r
replace kg = kg_r

replace kp=kp*22725.4/100
replace kd=kd*3014.9/100
replace kg=kg*5712.7/100

/* VARIABLES ARE EXPRESSED AT ANNUAL RATES */

/* augmented real measured capital */

gen kpd  = kp+kd
gen kpg  = kp+kg
gen kpdg = kp+kd+kg

/* augmented nominal measured output */

gen gnpd  = gnp_c+yd
gen gnpg  = gnp_c+yg
gen gnpdg = gnp_c+yd+yg


/* get real measured output */

replace gnpd	 = gnpd*100/gnp_defl
replace gnpg	 = gnpg*100/gnp_defl
replace gnpdg	 = gnpdg*100/gnp_defl

/* Take Logs */

gen lnkp   = ln(kp)
gen lnkpd  = ln(kpd)
gen lnkpg  = ln(kpg)
gen lnkpdg = ln(kpdg)

gen lngnpd  = ln(gnpd)
gen lngnpg  = ln(gnpg)
gen lngnpdg = ln(gnpdg)

gen lnn=ln(n)
gen lnhours=ln(hours)


/*-------------*/
/* generate z0 */
/*-------------*/

gen z0    = lngnp    - av_theta*(lnkp)     - (1-av_theta)*(lnh) 
gen z0d   = lngnpd   - av_thetad*(lnkpd)   - (1-av_thetad)*(lnh) 
gen z0g   = lngnpg   - av_thetag*(lnkpg)   - (1-av_thetag)*(lnh) 
gen z0dg  = lngnpdg  - av_thetadg*(lnkpdg) - (1-av_thetadg)*(lnh)

gen zz0   = gnp/((kp^(av_theta))*(h^(1-av_theta)))
gen zz0d  = gnpd/((kpd^(av_thetad))*(h^(1-av_thetad)))
gen zz0g  = gnpg/((kpg^(av_thetag))*(h^(1-av_thetag)))
gen zz0dg = gnpdg/((kpdg^(av_thetadg))*(h^(1-av_thetadg)))

/*-------------*/
/* generate z1 */
/*-------------*/

gen z1     = lngnp   - (1-LS)*(lnkp)     - LS*(lnh)      
gen z1d    = lngnpd  - (1-LSd)*(lnkpd)   - LSd*(lnh) 
gen z1g    = lngnpg  - (1-LSg)*(lnkpg)   - LSg*(lnh) 
gen z1dg   = lngnpdg - (1-LSdg)*(lnkpdg) - LSdg*(lnh) 

gen zz1   = gnp/((kp^(1-LS))*(h^(LS)))
gen zz1d  = gnpd/((kpd^(1-LSd))*(h^(LSd)))
gen zz1g  = gnpg/((kpg^(1-LSg))*(h^(LSg)))
gen zz1dg = gnpdg/((kpdg^(1-LSdg))*(h^(LSdg)))



/*log using "F:\VAR5\CORRELATIONS_1.txt", replace*/

corr z0    z1    LS    lngnp
corr z0d   z1d   LSd   lngnpd
corr z0g   z1g   LSg   lngnpg
corr z0dg  z1dg  LSdg  lngnpdg

/*log close*/



/*------------------------------------------*/
/* generate HP filtered series of z0 and z1 */
/* 	that is, generate e0 and e1 	    */
/*------------------------------------------*/

/* STATA 9 */

hprescott8 lngnpd,  stub(h) smooth(1600)
hprescott8 lngnpg,  stub(h) smooth(1600)
hprescott8 lngnpdg, stub(h) smooth(1600)
hprescott8 lnkp,    stub(h) smooth(1600)
hprescott8 lnkpd,   stub(h) smooth(1600)
hprescott8 lnkpg,   stub(h) smooth(1600)
hprescott8 lnkpdg,  stub(h) smooth(1600)
hprescott8 lnn,     stub(h) smooth(1600)
hprescott8 lnhours, stub(h) smooth(1600)

gen elngnpd  = h_lngnpd_1
gen elngnpg  = h_lngnpg_1
gen elngnpdg = h_lngnpdg_1
gen elnkp    = h_lnkp_1
gen elnkpd   = h_lnkpd_1
gen elnkpg   = h_lnkpg_1
gen elnkpdg  = h_lnkpdg_1
gen elnn     = h_lnn_1
gen elnhours = h_lnhours_1


gen ez0    = elngnp    - av_theta*(elnkp)     - (1-av_theta)*(elnh) 
gen ez0d   = elngnpd   - av_thetad*(elnkpd)   - (1-av_thetad)*(elnh) 
gen ez0g   = elngnpg   - av_thetag*(elnkpg)   - (1-av_thetag)*(elnh) 
gen ez0dg  = elngnpdg  - av_thetadg*(elnkpdg) - (1-av_thetadg)*(elnh)
gen ez1     = elngnp   - (1-LS)*(elnkp)     - LS*(elnh)      
gen ez1d    = elngnpd  - (1-LSd)*(elnkpd)   - LSd*(elnh) 
gen ez1g    = elngnpg  - (1-LSg)*(elnkpg)   - LSg*(elnh) 
gen ez1dg   = elngnpdg - (1-LSdg)*(elnkpdg) - LSdg*(elnh)

hprescott8 z0, stub(h) smooth(1600)
hprescott8 z0d, stub(h) smooth(1600)
hprescott8 z0g, stub(h) smooth(1600)
hprescott8 z0dg, stub(h) smooth(1600)
hprescott8 z1, stub(h) smooth(1600)
hprescott8 z1d, stub(h) smooth(1600)
hprescott8 z1g, stub(h) smooth(1600)
hprescott8 z1dg, stub(h) smooth(1600)

replace ez0   = h_z0_1
replace ez0d  = h_z0d_1
replace ez0g  = h_z0g_1
replace ez0dg = h_z0dg_1
replace ez1   = h_z1_1
replace ez1d  = h_z1d_1
replace ez1g  = h_z1g_1
replace ez1dg = h_z1dg_1



/* STATA 8 */

/*

hpfilter lngnp,   lambda(1600)
hpfilter lngnpd,  lambda(1600)
hpfilter lngnpg,  lambda(1600)
gen cr=lngnpdg
hpfilter cr, lambda(1600)
hpfilter lnkp,    lambda(1600)
hpfilter lnkpd,   lambda(1600)
hpfilter lnkpg,   lambda(1600)
hpfilter lnkpdg,  lambda(1600)
hpfilter lnh,     lambda(1600)

gen elngnp   = lngnp   - H_lngnp
gen elngnpd  = lngnpd  - H_lngnpd
gen elngnpg  = lngnpg  - H_lngnpg
gen elngnpdg = lngnpdg - H_cr
gen elnkp    = lnkp    - H_lnkp
gen elnkpd   = lnkpd   - H_lnkpd
gen elnkpg   = lnkpg   - H_lnkpg
gen elnkpdg  = lnkpdg  - H_lnkpdg
gen elnh     = lnh     - H_lnh


gen ez0    = elngnp    - av_theta*(elnkp)     - (1-av_theta)*(elnh) 
gen ez0d   = elngnpd   - av_thetad*(elnkpd)   - (1-av_thetad)*(elnh) 
gen ez0g   = elngnpg   - av_thetag*(elnkpg)   - (1-av_thetag)*(elnh) 
gen ez0dg  = elngnpdg  - av_thetadg*(elnkpdg) - (1-av_thetadg)*(elnh)
gen ez1     = elngnp   - (1-LS)*(elnkp)     - LS*(elnh)      
gen ez1d    = elngnpd  - (1-LSd)*(elnkpd)   - LSd*(elnh) 
gen ez1g    = elngnpg  - (1-LSg)*(elnkpg)   - LSg*(elnh) 
gen ez1dg   = elngnpdg - (1-LSdg)*(elnkpdg) - LSdg*(elnh)

hpfilter z0,    lambda(1600)
hpfilter z0d,   lambda(1600)
hpfilter z0g,   lambda(1600)
hpfilter z0dg,  lambda(1600)
hpfilter z1,    lambda(1600)
hpfilter z1d,   lambda(1600)
hpfilter z1g,   lambda(1600)
hpfilter z1dg,  lambda(1600)

replace ez0   = z0   - H_z0
replace ez0d  = z0d  - H_z0d
replace ez0g  = z0g  - H_z0g
replace ez0dg = z0dg - H_z0dg
replace ez1   = z1   - H_z1
replace ez1d  = z1d  - H_z1d
replace ez1g  = z1g  - H_z1g
replace ez1dg = z1dg - H_z1dg

*/

/*--------------------------------*/









/*---------------- end of program -------------------*/




