% Dynare MOD-File: Solves RBC in "Redistributive and Productivity Shocks"
% Jose-Victor Rios-Rull and Raul Santaeulalia-Llopis JME, 2010

close all;

%----------------------------------------------------------------
% 1. Variables Definition
%----------------------------------------------------------------

var y h c i w y_h r z1 z2 LS LS_aux z0 k y_k r1 r2 w1 w2;
varexo e1 e2;

parameters theta delta rho11 rho12 rho21 rho22 sigma1 sigma2 gamma beta alpha eta mu mud mudg A Ad Adg kappa;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------

    eta    = .0044453  ;
    theta  = .320511;
    delta  = .01886752642446388;
    beta   = .988108524026222;
    gamma  = .003677950407055652;
    alpha  = .668495246884850;
    A      = .108028505697855;
    mu     = 29.8606967741935;
    kappa  = 2.92;


%----------------------------------------------------------------
% 3. Properties of Univariate and Bivariate Shock 
%----------------------------------------------------------------
    
    % UNIVARIATE 
    %   rho11  =  .958;
    %   rho12  =  .000;
    %   rho21  =  .000;
    %   rho22  =  .000;
    %   sigma1 =  .00672;  
    %   sigma2 =  .00;
    %   psi    =  .00;    

       
    % BIVARIATE
        rho11  =  .952122;
        rho12  = -.00479;
        rho21  =  .050004;
        rho22  =  .931352;
        sigma1 =  .006752;  
        sigma2 =  .003047;
        psi    = -.00001065153;

    % BIVARIATE - WITH ROUNDING
    %   rho11  =  .952;
    %   rho12  = -.004;
    %   rho21  =  .050;
    %   rho22  =  .931;
    %   sigma1 =  .00675;  
    %   sigma2 =  .00304;
    %   psi    = -.00001065;
        
        
%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------


% Standard RBC Model, FOC h: 
%  alpha*c/(1-h)=(1-alpha)*w;

% Hansen-Rogerson, FOC h: 
%  kappa=(1-alpha)*w/c;


model;

  alpha*c/(1-h)=(1-alpha)*w;
  (1+gamma)/c = beta*(1/c(+1))*(1-delta+r(+1));
  y = (A)*exp(z1)*(k(-1)^(theta-z2))*((h*mu)^(1-theta+z2));
  r=(theta-z2)*y/k(-1);
  r1=r(+1);
  r2=r(+2);
  w=(1-theta+z2)*y/h;
  w1=(1-theta+z2(+1))*y(+1)/h(+1);
  w2=(1-theta+z2(+2))*y(+2)/h(+2);
  i = (1+gamma)*(1+eta)*k-(1-delta)*k(-1);
  c+i = y;
  y_h = y/h;
  z1 = rho11*z1(-1)+rho12*z2(-1)+e1;
  z2 = rho21*z1(-1)+rho22*z2(-1)+e2;
  LS_aux= log(1-theta+z2)-log(1-theta);
  LS = (1-theta)*exp(LS_aux);
  z0=y/((A)*((k(-1)^theta(-1))*((mu*h)^(1-theta))));
  y_k=y/k(-1);

end;



%----------------------------------------------------------------
% 4. Computation
%----------------------------------------------------------------

initval;     
  k = .33*mu;   
  c = .03*mu; 
  h = 0.33; 
  z1 = 0;   
  z2 = 0;    
  e1 = 0;    
  e2 = 0;    
end;

shocks;
var e1 = sigma1^2;
var e2 = sigma2^2;
var e1,e2 = psi;
end;

steady;


% IRF HP-Filtered
    stoch_simul(hp_filter = 1600, order = 1, IRF=50, replic=10);
%   stoch_simul(order = 1, IRF=50, replic=10);
% RELATIVE IRF 
%  stoch_simul(hp_filter = 1600, order = 1, IRF=50, relative_irf, replic=10);
% IRF non-HP-Filtered
%   stoch_simul(order = 1, IRF=50, replic=10);
% SIMULATION   
%  stoch_simul(order = 1, periods =1000, simul, relative_irf, replic=10);


%----------------------------------------------------------------
% 5. Reporting Results
%----------------------------------------------------------------

stats1 =  sqrt(diag(oo_.var(1:18,1:18)));
stats2 =  oo_.mean(1:18);
statistic1 = 100*sqrt(diag(oo_.var(1:18,1:18)))./oo_.mean(1:18);
statistic2 = (statistic1(1:18)).^2;

% HP-filtered Variance:
dyntable('Relative (to mean) Variance in %',strvcat('VARIABLE','VARIANCE'),M_.endo_names(1:18,:),statistic2,10,8,4);



% IN ORDER TO COMPUTE IRFS WITH RESPECT TO STEADY STATE, 
% DIVIDE THE OUTCOME IMPULSE RESPONSE of X 
% BY THE STEADY STATE of THAT VARIABLE X
% For instance, Impulse Response of Hours
% IRF_h_e1= h_e1/.31;

% IN ORDER TO SHUT SHOCKS, GO TO SIMULT.M AND ACTIVATE/DEACTIVATE:
% shut u2 ->
% chol_S(2,2)=0
% shut u1 ->
% chol_S(1,2)=0
% chol_S(1,1)=0
